/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.eventbus;

/**
 * Interface for GuiEvents
 * atm only the GuiEventKey accessor is specified,
 * later an event message object could be added to provide short lined information
 * deliverance.
 * 
 * {@link BaseGuiEventProducer} provides a runtime implementation for GuiEvent in
 * the triggerEvent methods, so usually it is not needed to provided an own implementation.
 * 
 * 
 * @author Timon Veenstra
 */
public interface GuiEvent<E> {

    /**
     * Gets the GuiEventKey for the GuiEvent
     * Used to match events to listeners.
     * Listeners implement {@link GuiEventListener#listensTo(nl.cloudfarming.eventbus.GuiEventKey) } which is based on
     * GuiEventKeys
     * 
     * @return
     */
    public GuiEventKey getKey();

    /**
     * Get the content of an GuiEvent. 
     * Normally this method will return null since most events don't carry any content
     * with them. If circumstances ask to provide some additional content with the event,
     * the content can be retrieved with this function. No guarentees are given about type
     * or content of the returned object so usage should be avoided, especually across modules.
     * Producing modules cannot change the content without breaking listening modules!
     * 
     * @return
     */
    public E getContent();
}
