/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.eventbus;


/**
 * GuiEventProducer interface, specifies signature for GuiEventProducers.
 * Implementations should extend {@link BaseGuiEventProducer} instead of
 * directly implementing this interface.
 * 
 * @author Timon Veenstra
 */
public interface GuiEventProducer {
    /**
     * Retrieve an array with GuiEventKeys registered by this producer 
     * 
     * @return
     */
    GuiEventKey[] getEventKeys();
   
    /**
     * Trigger an event with a key.
     * The key must either be a {@link GlobalGuiEventKey} or the {@link GuiEventKey} registered
     * by this producer.
     * 
     * @param guiEventKey
     */
    void triggerEvent(GuiEventKey guiEventKey);
    
    /**
     * Trigger an event with a key and an object as content.
     * The key must either be a {@link GlobalGuiEventKey} or the {@link GuiEventKey} registered
     * by this producer.
     * The content can just be any Object, so producers should be certain that listeners expect what 
     * they put into it.
     * Dont use this for complex or large objects
     * 
     * @param guiEventKey
     * @param content
     */
    void triggerEvent(GuiEventKey guiEventKey,Object content);
}
